@@ -85,8 +85,8 @@ options:
         description:
             - If C(yes), any modified files in the working
               repository will be discarded.  Prior to 0.7, this was always
-              'yes' and could not be disabled.  Prior to 1.9, the default was
-              `yes`.
+              C(yes) and could not be disabled.  Prior to 1.9, the default was
+              C(yes).
         type: bool
         default: 'no'
         version_added: "0.7"
@@ -141,7 +141,7 @@ options:
 
     single_branch:
         description:
-            - Clone only the history leading to the tip of the specified I(branch).
+            - Clone only the history leading to the tip of the specified revision.
         type: bool
         default: 'no'
         version_added: '2.11'
@@ -259,8 +259,10 @@ EXAMPLES = '''
 
 - name: Example clone of a single branch
   ansible.builtin.git:
+    repo: https://github.com/ansible/ansible-examples.git
+    dest: /src/ansible-examples
     single_branch: yes
-    branch: master
+    version: master
 
 - name: Avoid hanging when http(s) password is missing
   ansible.builtin.git:
